@@ -1,4 +1,3 @@
-import chunk
 import enum
 import os
 import sys
@@ -9,6 +8,7 @@ import requests
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
+from itertools import islice
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
 OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
@@ -36,25 +36,29 @@ class Network3Medusa():
             info = query.execute(self.client)
             print("File size according to `FileInfoQuery`: ", info.size)
         else:
-            json_dict = json.load(raw_json)
-            chunkSize = 6000
+            json_dict = json.loads(raw_json)
             first = True
-            for item in range(0,len(json_dict), chunkSize):
+            for item in self.chunks({i:i for i in json_dict}):
                 if first:
+                    first = False
                     print("first")
                     print(item)
-                    first = False
-                    self.add_file_to_hedera(item)
+                    #self.add_file_to_hedera(item)
                 else:
-                    print("not first")
+                    [print("not first")]
                     print(item)
-                    self.append_file_to_hedera(item)
+                    #self.append_file_to_hedera(item)
             query = FileInfoQuery().setFileId(self.fileId)
             info = query.execute(self.client)
             print("File size according to `FileInfoQuery`: ", info.size)            
             if WEBEX_ROOM:
                 self.send_webex_notification()
 
+    def chunks(self, data, SIZE=6000):
+        it = iter(data)
+        for i in range(0, len(data), SIZE):
+            yield {k:data[k] for k in islice(it, SIZE)}
+
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
